import 'package:alan/alan.dart';
import 'package:test/test.dart';

import 'package:alan/proto/cosmos/bank/v1beta1/export.dart' as bank;

void main() {
  final networkInfo = NetworkInfo.fromSingleHost(
    bech32Hrp: 'desmos',
    host: 'http://localhost',
  );

  final mnemonic = [
    'sibling',
    'auction',
    'sibling',
    'flavor',
    'judge',
    'foil',
    'tube',
    'dust',
    'work',
    'mixed',
    'crush',
    'action',
    'menu',
    'property',
    'project',
    'ride',
    'crouch',
    'hat',
    'mom',
    'scale',
    'start',
    'ill',
    'spare',
    'panther',
  ];

  test('Create and send transactions', () async {
    final wallet = Wallet.derive(
      mnemonic,
      networkInfo,
      derivationPath: "m/852'/0'/0'/0",
    );

    // Create your message
    final message = bank.MsgSend.create();
    message.fromAddress = wallet.bech32Address;
    message.toAddress = 'desmos16d249e8puma6pzr5azkfgj26vefmc4j42lvzk3';

    final coin = Coin.create();
    coin.denom = 'udaric';
    coin.amount = '100';

    message.amount.add(coin);

    // Build the signer
    final signer = TxSigner.fromNetworkInfo(networkInfo);

    // Fee
    final fee = Fee.create();
    fee.gasLimit = 200000.toInt64();

    // Create and sign the transaction
    final signedTx = await signer.createAndSign(
      wallet,
      [message],
      memo: 'Optional memo', // Optional
      fee: fee, // Optional (Default is 200000 gas and empty amount)
    );

    final sender = TxSender.fromNetworkInfo(networkInfo);
    final result = await sender.broadcastTx(signedTx);
    print(result);
  });
}
